#
# spec file for package python-slimit
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%define oldpython python
Name:           python-slimit
Version:        0.8.1
Release:        10.1
Summary:        JavaScript minifier written in Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://slimit.readthedocs.io/
Source:         https://files.pythonhosted.org/packages/source/s/slimit/slimit-%{version}.zip
# PATCH-FIX-OPENSUSE python-slimit-add-licence.patch -- Include the licence file that is present in git since 4111f2d.
Patch0:         python-slimit-add-licence.patch
# https://github.com/rspivak/slimit/commit/40956e7fc6e954b3e6d7b629faeb3303f5efb7ea
Patch1:         python-slimit-fix-python3.patch
BuildRequires:  %{python_module ply >= 3.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# SECTION test requirements
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-ply >= 3.4
Requires:       python-setuptools
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
%ifpython2
# python-slimit was last used in openSUSE Leap 15.0.
Provides:       %{oldpython}-slimit = %{version}
Obsoletes:      %{oldpython}-slimit < %{version}
%endif

%description
SlimIt is a JavaScript minifier written in Python. It compiles
JavaScript into more compact code so that it downloads and runs
faster.

SlimIt also provides a library that includes a JavaScript parser,
lexer, pretty printer and a tree visitor.

%python_subpackages

%prep
%setup -q -n slimit-%{version}
%patch0 -p1
%patch1 -p1

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/
%python_clone -a %{buildroot}%{_bindir}/slimit

%post
%python_install_alternative slimit

%postun
%python_uninstall_alternative slimit

%check
%pytest

%files %{python_files}
%license LICENSE
%doc CHANGES README.rst
%python_alternative %{_bindir}/slimit
%{python_sitelib}/slimit/
%{python_sitelib}/slimit-*

%changelog
* Wed Jun 21 2023 Andreas Schneider <asn@cryptomilk.org>
- Use sle15_python_module_pythons
* Thu Jun 20 2019 pgajdos@suse.com
- run the testsuite, make it passing
- modified patches
  https://github.com/rspivak/slimit/commit/40956e7fc6e954b3e6d7b629faeb3303f5efb7ea
  %% python-slimit-fix-python3.patch (amended)
* Thu Jan 31 2019 Tomáš Chvátal <tchvatal@suse.com>
- Drop odict, not really required from python 2.7+
* Sat Jun 30 2018 sor.alexei@meowr.ru
- Update for the multipython build.
- Do not run tests: there aren't any.
- Add python-slimit-add-licence.patch: Include the licence file
  that is present in git since 4111f2d.
- Add python-slimit-fix-python3.patch: Take commit e833165 from
  https://github.com/rspivak/slimit/pull/65 by Lele Gaifax.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Sep 10 2013 os-dev@jacraig.com
- Update to 0.8.1:
  * Bug fix: Fix syntax error in the output of for statement with some form of
    expressions
- Changes from 0.8.0:
  * Python 3.x support
  * Bug fix: slimit removes parentheses from ternary expression, causes syntax
    error in jQuery
  * Bug fix: simple identifier in FOR init
  * Bug fix: using $ for mangled function names conflicts with jQuery
* Thu Sep  5 2013 os-dev@jacraig.com
- Add requires for odict and ply >= 3.4, they are necessary to run slimit.
* Fri Jun 22 2012 os-dev@jacraig.com
- Update to 0.7.4:
  * Bug fix: https://github.com/rspivak/slimit/issues/34 'class' is reserved
    keyword now
- Changes from 0.7 to 0.7.3:
  * Bug fix (unary op in FOR init)
  * Added support for get/set properties
  * Function call support in FOR init section
  * Multiline string support
- Added >= 3.4 to python-ply requirement, setup.py indicates that version
* Tue Apr 10 2012 saschpe@suse.de
- Update to version 0.6.2:
  * Better multiline handling
* Mon Mar 12 2012 saschpe@suse.de
- Initial version
